==> libyui-qt-pkg-2.45.15.2.tar.bz2: libyui-qt-pkg-2.45.15.2/SOURCECONF.cmake <==
SET( ${TARGETLIB}_SOURCES
  ##### Here go the source files
  QY2LayoutUtils.cc
  YQIconPool.cc
  YQPackageSelectorBase.cc
  YQPackageSelector.cc
  YQPackageSelectorHelp.cc
  YQPatternSelector.cc
  YQSimplePatchSelector.cc
  YQPkgChangeLogView.cc
  YQPkgChangesDialog.cc
  YQPkgConflictDialog.cc
  YQPkgConflictList.cc
  YQPkgDependenciesView.cc
  YQPkgDescriptionDialog.cc
  YQPkgDescriptionView.cc
  YQPkgDiskUsageList.cc
  YQPkgDiskUsageWarningDialog.cc
  YQPkgFileListView.cc
  YQPkgFilters.cc
  YQPkgFilterTab.cc
  YQPkgGenericDetailsView.cc
  YQPkgHistoryDialog.cc
  YQPkgLangList.cc
  YQPkgList.cc
  YQPkgObjList.cc
  YQPkgPackageKitGroupsFilterView.cc
  YQPkgPatchFilterView.cc
  YQPkgPatchList.cc
  YQPkgPatternList.cc
  YQPkgProductDialog.cc
  YQPkgProductList.cc
  YQPkgRepoFilterView.cc
  YQPkgRepoList.cc
  YQPkgRpmGroupTagsFilterView.cc
  YQPkgSearchFilterView.cc
  YQPkgSecondaryFilterView.cc
  YQPkgSelDescriptionView.cc
  YQPkgSelMapper.cc
  YQPkgServiceFilterView.cc
  YQPkgServiceList.cc
  YQPkgStatusFilterView.cc
  YQPkgTechnicalDetailsView.cc
  YQPkgTextDialog.cc
  YQPkgUpdateProblemFilterView.cc
  YQPkgVersionsView.cc
  YQPackageSelectorPluginImpl.cc
  YQZyppSolverDialogPluginStub.cc
)

SET( ${TARGETLIB}_HEADERS
  ##### Here go the headers
  QY2LayoutUtils.h
  YQIconPool.h
  YQPackageSelector.h
  YQPackageSelectorBase.h
  YQPackageSelectorPlugin.h
  YQPackageSelectorPluginImpl.h
  YQPatternSelector.h
  YQPkgChangeLogView.h
  YQPkgChangesDialog.h
  YQPkgConflictDialog.h
  YQPkgConflictList.h
  YQPkgDependenciesView.h
  YQPkgDescriptionDialog.h
  YQPkgDescriptionView.h
  YQPkgDiskUsageList.h
  YQPkgDiskUsageWarningDialog.h
  YQPkgFileListView.h
  YQPkgFilters.h
  YQPkgFilterTab.h
  YQPkgGenericDetailsView.h
  YQPkgHistoryDialog.h
  YQPkgLangList.h
  YQPkgList.h
  YQPkgObjList.h
  YQPkgPackageKitGroupsFilterView.h
  YQPkgPatchFilterView.h
  YQPkgPatchList.h
  YQPkgPatternList.h
  YQPkgProductDialog.h
  YQPkgProductList.h
  YQPkgRepoFilterView.h
  YQPkgRepoList.h
  YQPkgRpmGroupTagsFilterView.h
  YQPkgSearchFilterView.h
  YQPkgSecondaryFilterView.h
  YQPkgSelDescriptionView.h
  YQPkgSelList.h
  YQPkgSelMapper.h
  YQPkgServiceFilterView.h
  YQPkgServiceList.h
  YQPkgStatusFilterView.h
  YQPkgTechnicalDetailsView.h
  YQPkgTextDialog.h
  YQPkgUpdateProblemFilterView.h
  YQPkgVersionsView.h
  YQSimplePatchSelector.h
  YQZypp.h
  YQZyppSolverDialogPluginIf.h
  YQZyppSolverDialogPluginStub.h
)

SET( EXAMPLES_LIST
  ##### Here go the examples
)

==> libyui-qt-pkg-2.45.28.tar.bz2: libyui-qt-pkg-2.45.28/SOURCECONF.cmake <==
set(CMAKE_AUTORCC ON)

SET( ${TARGETLIB}_SOURCES
  ##### Here go the source files
  QY2LayoutUtils.cc
  YQIconPool.cc
  YQPackageSelectorBase.cc
  YQPackageSelector.cc
  YQPackageSelectorHelp.cc
  YQPatternSelector.cc
  YQSimplePatchSelector.cc
  YQPkgChangeLogView.cc
  YQPkgChangesDialog.cc
  YQPkgConflictDialog.cc
  YQPkgConflictList.cc
  YQPkgDependenciesView.cc
  YQPkgDescriptionDialog.cc
  YQPkgDescriptionView.cc
  YQPkgDiskUsageList.cc
  YQPkgDiskUsageWarningDialog.cc
  YQPkgFileListView.cc
  YQPkgFilters.cc
  YQPkgFilterTab.cc
  YQPkgGenericDetailsView.cc
  YQPkgHistoryDialog.cc
  YQPkgLangList.cc
  YQPkgList.cc
  YQPkgObjList.cc
  YQPkgPackageKitGroupsFilterView.cc
  YQPkgPatchFilterView.cc
  YQPkgPatchList.cc
  YQPkgPatternList.cc
  YQPkgProductDialog.cc
  YQPkgProductList.cc
  YQPkgRepoFilterView.cc
  YQPkgRepoList.cc
  YQPkgSearchFilterView.cc
  YQPkgSecondaryFilterView.cc
  YQPkgSelDescriptionView.cc
  YQPkgSelMapper.cc
  YQPkgServiceFilterView.cc
  YQPkgServiceList.cc
  YQPkgStatusFilterView.cc
  YQPkgTechnicalDetailsView.cc
  YQPkgTextDialog.cc
  YQPkgUpdateProblemFilterView.cc
  YQPkgVersionsView.cc
  YQPackageSelectorPluginImpl.cc
  qt_pkg_icons.qrc
)

SET( ${TARGETLIB}_HEADERS
  ##### Here go the headers
  QY2LayoutUtils.h
  YQIconPool.h
  YQPackageSelector.h
  YQPackageSelectorBase.h
  YQPackageSelectorPlugin.h
  YQPackageSelectorPluginImpl.h
  YQPatternSelector.h
  YQPkgChangeLogView.h
  YQPkgChangesDialog.h
  YQPkgConflictDialog.h
  YQPkgConflictList.h
  YQPkgDependenciesView.h
  YQPkgDescriptionDialog.h
  YQPkgDescriptionView.h
  YQPkgDiskUsageList.h
  YQPkgDiskUsageWarningDialog.h
  YQPkgFileListView.h
  YQPkgFilters.h
  YQPkgFilterTab.h
  YQPkgGenericDetailsView.h
  YQPkgHistoryDialog.h
  YQPkgLangList.h
  YQPkgList.h
  YQPkgObjList.h
  YQPkgPackageKitGroupsFilterView.h
  YQPkgPatchFilterView.h
  YQPkgPatchList.h
  YQPkgPatternList.h
  YQPkgProductDialog.h
  YQPkgProductList.h
  YQPkgRepoFilterView.h
  YQPkgRepoList.h
  YQPkgSearchFilterView.h
  YQPkgSecondaryFilterView.h
  YQPkgSelDescriptionView.h
  YQPkgSelList.h
  YQPkgSelMapper.h
  YQPkgServiceFilterView.h
  YQPkgServiceList.h
  YQPkgStatusFilterView.h
  YQPkgTechnicalDetailsView.h
  YQPkgTextDialog.h
  YQPkgUpdateProblemFilterView.h
  YQPkgVersionsView.h
  YQSimplePatchSelector.h
  YQZypp.h
)

SET( EXAMPLES_LIST
  ##### Here go the examples
)
